/*  Glimmer - about.c
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "declarations.h"
#include "about.h"

void
do_about (GtkWidget * widget, gpointer data)
{
    GtkWidget *about_window;
    const gchar *author[] = { "Chris Phelps <chicane@reninet.com>", NULL };

    about_window = gnome_about_new (PACKAGE, "v" VERSION,
                                    "Copyright 1999-2000 by Chris Phelps",
                                    author,
                                    "Report bugs/crash problems to chicane@reninet.com\n"
                                    URL_WEB "\n\n" PACKAGE
                                    " is a versatile editing environment\n"
                                    "for nearly any type of code.",
                                    "glimmer-title.png");
    gtk_widget_show (about_window);
}
